.. image:: https://raw.githubusercontent.com/openforis/sepal-doc/master/docs/source/_images/sepal_header.png

Sepal_ui
--------

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
    :target: https://opensource.org/licenses/MIT
    :alt: License: MIT

.. image:: https://badge.fury.io/py/sepal-ui.svg
    :target: https://badge.fury.io/py/sepal-ui
    :alt: PyPI version
    
.. image:: https://img.shields.io/pypi/dm/sepal-ui?color=307CC2&logo=python&logoColor=gainsboro  
    :target: https://pypi.org/project/sepal-ui/
    :alt: PyPI - Downloads
    
.. image:: https://img.shields.io/pypi/pyversions/sepal-ui
   :target: https://pypi.org/project/sepal-ui/
   :alt: supported Python version

.. image:: https://github.com/12rambau/sepal_ui/actions/workflows/unit.yml/badge.svg
    :target: https://github.com/12rambau/sepal_ui/actions/workflows/unit.yml
    :alt: build

.. image:: https://api.codeclimate.com/v1/badges/861f09002bb9d75b6ea5/maintainability
    :target: https://codeclimate.com/github/12rambau/sepal_ui/maintainability
    :alt: Maintainability

.. image:: https://codecov.io/gh/12rambau/sepal_ui/branch/master/graph/badge.svg?token=YZ3mVcuaCq
    :target: https://codecov.io/gh/12rambau/sepal_ui
    :alt: Test Coverage
    
.. image:: https://readthedocs.org/projects/sepal-ui/badge/?version=latest
    :target: https://sepal-ui.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
    
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black badge
   
.. image:: https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg
   :target: https://conventionalcommits.org
   :alt: conventional commit

:code:`sepal_ui` is a lib designed to create elegant python based dashboard in the SEPAL environment. It is designed on top of the amazing `ipyvuetify <https://ipyvuetify.readthedocs.io/en/latest/introduction.html>`_ library and will help developer to easily create interface for their workflows. 
By using this libraries, you'll ensure a robust and unified interface for your scripts and a easy and complete integration into the SEPAL dashboard of application.

The full documentation is available `here <https://sepal-ui.readthedocs.io/en/latest/>`__ and a demo app can be launched on Heroku following this link: `<https://sepal-ui.herokuapp.com>`__.

We are happy to receive feedback and we welcome any kind of contribution

.. image:: https://raw.githubusercontent.com/12rambau/sepal_ui/master/docs/source/_image/sepal_ui_demo.gif

Contribute
----------

If you want to contribute you can fork the project in you own repository and then use it. 
If you consider working with us, please follow the `contributing guidelines <https://github.com/12rambau/sepal_ui/blob/master/CONTRIBUTING.rst>`_. 
Meet our `contributor <https://github.com/12rambau/sepal_ui/blob/master/AUTHORS.rst>`_. 

